@@ -1,6 +1,5 @@
 from dataclasses import dataclass, field
 from typing import Dict, Any, Optional, List
-import random
 import sys
 
 @dataclass(frozen = True)
@@ -12,8 +11,6 @@ class BaseNaipy:
 class DetectNaipy(BaseNaipy):
   langCode : Optional[str] = field(repr=True, compare=True, default=None)
   """언어코드"""
-  type : Optional[str] = field(repr=True, compare=True, default=None)
-  """return Detect"""
   
 @dataclass(frozen = True)
 class N2mtNaipy(BaseNaipy):
@@ -37,14 +34,12 @@ class N2mtNaipy(BaseNaipy):
     result = {
       "srcLangType" : self.srcLangType,
       "tarLangType" : self.tarLangType,
-      'text' : self.text
+      'text' : self.translatedText
     }
     return result
 
 @dataclass(frozen = True)
 class SearchNaipy(BaseNaipy):
-  type : Optional[str] = field(repr=True, compare=True, default=None)
-  """검색 타입"""
   lastBuildDate : Optional[str] = field(repr=True, compare=True, default=None)
   """검색 결과를 생성한 시간"""
   total : Optional[int] = field(repr=True, compare=True, default=None)
